Method: ActiveAdmin::Inputs::FilterStringInput#to_html
- Defined in:
- lib/active_admin/inputs/filter_string_input.rb
#to_html ⇒ Object
If the filter method includes a search condition, build a normal string search field. Else, build a search field with a companion dropdown to choose a search condition from.
11 12 13 14 15 16 17 18 19 20 |
# File 'lib/active_admin/inputs/filter_string_input.rb', line 11 def to_html if seems_searchable? input_wrapping do label_html << builder.text_field(method, ) end else super # SearchMethodSelect#to_html end end |